Module: SchleuderCli::SubcommandFix
- Included in:
- Keys, Lists, Subscriptions
- Defined in:
- lib/schleuder-cli/subcommand_fix.rb
Instance Method Summary collapse
-
#banner(task, namespace = true, subcommand = true) ⇒ Object
Fixing a bug in Thor where the actual subcommand wouldn’t show up with some invocations of the help-output.
Instance Method Details
#banner(task, namespace = true, subcommand = true) ⇒ Object
Fixing a bug in Thor where the actual subcommand wouldn’t show up with some invocations of the help-output.
6 7 8 |
# File 'lib/schleuder-cli/subcommand_fix.rb', line 6 def (task, namespace = true, subcommand = true) "#{basename} #{task.formatted_usage(self, true, subcommand).split(':').join(' ')}" end |